@@ -1,5 +1,5 @@
 package MooX::BuildArgsHooks;
-$MooX::BuildArgsHooks::VERSION = '0.02';
+$MooX::BuildArgsHooks::VERSION = '0.03';
 =head1 NAME
 
 MooX::BuildArgsHooks - Structured BUILDARGS.
@@ -38,7 +38,7 @@ MooX::BuildArgsHooks - Structured BUILDARGS.
 =head1 DESCRIPTION
 
 This module installs some hooks directly into L<Moo> which allow
-for more fine-grained access to the phases of C<BUILDLARGS>.  The
+for more fine-grained access to the phases of C<BUILDARGS>.  The
 reason this is important is because if you have various roles and
 classes modifying BUILDARGS you will often end up with weird
 behaviors depending on what order the various BUILDARGS wrappers
@@ -79,7 +79,7 @@ use namespace::clean;
 
 BEGIN {
     package MooX::BuildArgsHooks::Test;
-$MooX::BuildArgsHooks::Test::VERSION = '0.02';
+$MooX::BuildArgsHooks::Test::VERSION = '0.03';
     use Moo;
     around BUILDARGS => sub{
         my $orig = shift;
@@ -145,7 +145,7 @@ BEGIN {
 # Must declare a custom no-op BUILDARGS otherwise
 # Method::Generate::Constructor gets in the way.
 # Alternatively we could modify its inlined BUILDARGS
-# to include our logic, but thats making things even
+# to include our logic, but that's making things even
 # more brittle.
 around BUILDARGS => sub{
     my $orig = shift;
@@ -261,7 +261,17 @@ L<MooX::SingleArg>
 
 =head1 AUTHOR
 
-Aran Clary Deltac <bluefeet@gmail.com>
+Aran Clary Deltac <bluefeetE<64>gmail.com>
+
+=head1 CONTRIBUTORS
+
+=over
+
+=item *
+
+Peter Pentchev <roamE<64>ringlet.net>
+
+=back
 
 =head1 LICENSE
 
